-- Onpub (TM)
-- Copyright (C) 2008 Onpubco <http://onpubco.com/>
-- Author: Corey HM Taylor <corey@onpubco.com>
--
-- This program is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; version 2.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
--
-- Requires SQLite version 3 or newer

CREATE TABLE OnpubImages (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  websiteID INTEGER NOT NULL,
  fileName VARCHAR(255) NOT NULL COLLATE NOCASE,
  description VARCHAR(255) NOT NULL COLLATE NOCASE,
  url VARCHAR(255) NOT NULL COLLATE NOCASE,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX images_websiteID ON OnpubImages (websiteID);
CREATE INDEX images_fileName ON OnpubImages (fileName);
CREATE INDEX images_description ON OnpubImages (description);
CREATE INDEX images_url ON OnpubImages (url);
CREATE INDEX images_created ON OnpubImages (created);
CREATE INDEX images_modified ON OnpubImages (modified);

CREATE TABLE OnpubWebsites (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  imageID INTEGER NULL,
  name VARCHAR(255) NOT NULL COLLATE NOCASE,
  url VARCHAR(255) NOT NULL COLLATE NOCASE,
  imagesURL VARCHAR(255) NOT NULL COLLATE NOCASE,
  imagesDirectory VARCHAR(255) NOT NULL COLLATE NOCASE,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX websites_imageID ON OnpubWebsites (imageID);
CREATE INDEX websites_name ON OnpubWebsites (name);
CREATE INDEX websites_url ON OnpubWebsites (url);
CREATE INDEX websites_imagesURL ON OnpubWebsites (imagesURL);
CREATE INDEX websites_imagesDirectory ON OnpubWebsites (imagesDirectory);
CREATE INDEX websites_created ON OnpubWebsites (created);
CREATE INDEX websites_modified ON OnpubWebsites (modified);

CREATE TABLE OnpubSections (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  imageID INTEGER NULL,
  websiteID INTEGER NOT NULL,
  parentID INTEGER NULL,
  name VARCHAR(255) NOT NULL COLLATE NOCASE,
  url VARCHAR(255) NOT NULL COLLATE NOCASE,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX sections_imageID ON OnpubSections (imageID);
CREATE INDEX sections_websiteID ON OnpubSections (websiteID);
CREATE INDEX sections_parentID ON OnpubSections (parentID);
CREATE INDEX sections_name ON OnpubSections (name);
CREATE INDEX sections_url ON OnpubSections (url);
CREATE INDEX sections_created ON OnpubSections (created);
CREATE INDEX sections_modified ON OnpubSections (modified);

CREATE TABLE OnpubArticles (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  imageID INTEGER NULL,
  title VARCHAR(255) NOT NULL COLLATE NOCASE,
  content MEDIUMTEXT NOT NULL COLLATE NOCASE,
  url VARCHAR(255) NOT NULL COLLATE NOCASE,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX articles_imageID ON OnpubArticles (imageID);
CREATE INDEX articles_title ON OnpubArticles (title);
CREATE INDEX articles_content ON OnpubArticles (content);
CREATE INDEX articles_url ON OnpubArticles (url);
CREATE INDEX articles_created ON OnpubArticles (created);
CREATE INDEX articles_modified ON OnpubArticles (modified);

CREATE TABLE OnpubAuthors (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  imageID INTEGER NULL,
  givenNames VARCHAR(255) NOT NULL COLLATE NOCASE,
  familyName VARCHAR(255) NOT NULL COLLATE NOCASE,
  displayAs VARCHAR(255) NOT NULL COLLATE NOCASE,
  url VARCHAR(255) NOT NULL COLLATE NOCASE,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX authors_imageID ON OnpubAuthors (imageID);
CREATE INDEX authors_givenNames ON OnpubAuthors (givenNames);
CREATE INDEX authors_familyName ON OnpubAuthors (familyName);
CREATE INDEX authors_displayAs ON OnpubAuthors (displayAs);
CREATE INDEX authors_url ON OnpubAuthors (url);
CREATE INDEX authors_created ON OnpubAuthors (created);
CREATE INDEX authors_modified ON OnpubAuthors (modified);

CREATE TABLE OnpubAAMaps (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  articleID INTEGER NOT NULL,
  authorID INTEGER NOT NULL,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX aamaps_articleID ON OnpubAAMaps (articleID);
CREATE INDEX aamaps_authorID ON OnpubAAMaps (authorID);
CREATE INDEX aamaps_created ON OnpubAAMaps (created);
CREATE INDEX aamaps_modified ON OnpubAAMaps (modified);

CREATE TABLE OnpubSAMaps (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  sectionID INTEGER NOT NULL,
  articleID INTEGER NOT NULL,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX samaps_sectionID ON OnpubSAMaps (sectionID);
CREATE INDEX samaps_articleID ON OnpubSAMaps (articleID);
CREATE INDEX samaps_created ON OnpubSAMaps (created);
CREATE INDEX samaps_modified ON OnpubSAMaps (modified);

CREATE TABLE OnpubWSMaps (
  ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
  websiteID INTEGER NOT NULL,
  sectionID INTEGER NOT NULL,
  created DATETIME NOT NULL,
  modified DATETIME NOT NULL
);

CREATE INDEX wsmaps_websiteID ON OnpubWSMaps (websiteID);
CREATE INDEX wsmaps_sectionID ON OnpubWSMaps (sectionID);
CREATE INDEX wsmaps_created ON OnpubWSMaps (created);
CREATE INDEX wsmaps_modified ON OnpubWSMaps (modified);
