<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2008, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.7
 */
class OnpubEditImages
{
    private $pdo;
    private $orderBy;
    private $order;
    private $page;
    private $keywords;
    private $fullTextSearch;
    private $sectionID;

    function __construct( PDO $pdo, $orderBy = null, $order = null, $page = null, $keywords = null, $fullTextSearch = null, $sectionID = null )
    {
        $this->pdo = $pdo;
        $this->orderBy = $orderBy;
        $this->order = $order;
        $this->page = $page;
        $this->keywords = $keywords;
        $this->fullTextSearch = $fullTextSearch;
        $this->sectionID = $sectionID;
    }

    public function display()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $this->fullTextSearch = "NA";
        $counter = 0;
        $currentPage = 1;

        if ( $this->page ) {
            $currentPage = $this->page;
        }

        if ( $this->orderBy && $this->order ) {
            if ( $this->keywords ) {
                try {
                    $queryOptions = new OnpubQueryOptions();
                    $queryOptions->orderBy = $this->orderBy;
                    $queryOptions->order = $this->order;

                    $images = $oimages->search( $this->keywords, $queryOptions );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubWidgetPDOException( $e );
                    $widget->display();
                    return;
                }

                $totalImages = sizeof( $images );
            }
            else {
                if ( $this->sectionID ) {

                }
                else {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = $this->orderBy;
                        $queryOptions->order = $this->order;
                        $queryOptions->setPage( $currentPage, ONPUBGUI_PDO_ROW_LIMIT );
                        $images = $oimages->select( $queryOptions );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    try {
                        $totalImages = $oimages->count();
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }
                }
            }
        }
        else {
            if ( $this->keywords ) {
                try {
                    $queryOptions = new OnpubQueryOptions();
                    $queryOptions->orderBy = "created";
                    $queryOptions->order = "DESC";

                    $images = $oimages->search( $this->keywords, $queryOptions );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubWidgetPDOException( $e );
                    $widget->display();
                    return;
                }

                $totalImages = sizeof( $images );
            }
            else {
                if ( $this->sectionID ) {

                }
                else {
                    try {
                        $queryOptions = new OnpubQueryOptions();
                        $queryOptions->orderBy = "created";
                        $queryOptions->order = "DESC";
                        $queryOptions->setPage( $currentPage, ONPUBGUI_PDO_ROW_LIMIT );
                        $images = $oimages->select( $queryOptions );
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }

                    try {
                        $totalImages = $oimages->count();
                    }
                    catch ( PDOException $e ) {
                        $widget = new OnpubWidgetPDOException( $e );
                        $widget->display();
                        return;
                    }
                }
            }
        }

        $widget = new OnpubWidgetHeader( "Edit Images" );
        $widget->display();

        echo '<form action="index.php" method="get">' . "\n";
        echo '<div><input type="hidden" name="onpub" value="EditImages" /></div>' . "\n";

        echo '<table border="0" cellpadding="3" cellspacing="2">' . "\n";

        if ( $totalImages ) {
            echo '<tr>' . "\n";
            $widget = new OnpubWidgetSearch( $totalImages, $this->keywords, "NA" );
            $widget->display();
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            $widget = new OnpubWidgetPaginator( $totalImages, $this->orderBy, $this->order, $this->page, $this->keywords, $this->fullTextSearch, "sectionID", $this->sectionID, "EditImages" );
            $widget->display();
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td></td>' . "\n";

            if ( $this->keywords ) {
                $this->keywords = urlencode( $this->keywords );

                if ( $this->fullTextSearch ) {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "fileName":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=DESC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;fullTextSearch=' . $this->fullTextSearch . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
                else {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "fileName":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=DESC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;keywords=' . $this->keywords . '&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }

                $this->keywords = urldecode( $this->keywords );
            }
            else {
                if ( $this->sectionID ) {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=ASC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "fileName":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=DESC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=ASC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC&sectionID=' . $this->sectionID . '">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC&sectionID=' . $this->sectionID . '">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=ASC&sectionID=' . $this->sectionID . '">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
                else {
                    switch ( $this->orderBy ) {
                        case "ID":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=ASC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        case "fileName":
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=DESC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                        default:
                        switch ( $this->order ) {
                            case "ASC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=DESC">Created</a></b></td>' . "\n";
                            break;
                            case "DESC":
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                            default:
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=ID&amp;order=DESC">ID</a></b></td>' . "\n";
                            echo '<td align="left"><b><a href="index.php?onpub=EditImages&amp;orderBy=fileName&amp;order=ASC">File Name</a></b></td>' . "\n";
                            echo '<td align="left" class="highlight2"><b><a href="index.php?onpub=EditImages&amp;orderBy=created&amp;order=ASC">Created</a></b></td>' . "\n";
                            break;
                        }
                        break;
                    }
                }
            }

            echo '</tr>' . "\n";

            if ( $this->keywords || $this->sectionID ) {
                $index = (($currentPage - 1) * ONPUBGUI_PDO_ROW_LIMIT);
            }
            else {
                $index = 0;
            }

            $websites = array();

            for ( $i = 0; $i < ONPUBGUI_PDO_ROW_LIMIT && $index < sizeof( $images ); $i++ ) {
                $websiteID = $images[$index]->websiteID;
                $ID = $images[$index]->ID;
                $fileName = $images[$index]->fileName;
                $created = $images[$index]->getCreated()->format( "M j, Y" );

                if ( !isset( $websites[$websiteID] ) ) {
                    $websites[$websiteID] = $owebsites->get( $websiteID );
                }

                echo '<tr valign="top">' . "\n";
                echo '<td align="right"><input type="checkbox" name="imageIDs[]" value="' . $ID . '" /></td>' . "\n";

                switch ( $this->order ) {
                    case "ASC":
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                    case "DESC":
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                    default:
                    switch ( $counter ) {
                        case 0:
                        echo '<td class="highlight1" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight1" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight1" align="left">' . $created . '</td>' . "\n";
                        break;
                        case 1:
                        echo '<td class="highlight2" align="right">' . $ID . '</td>' . "\n";
                        echo '<td class="highlight2" align="left"><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit">' . $fileName . '</a></td>' . "\n";
                        echo '<td class="highlight2" align="left">' . $created . '</td>' . "\n";
                        break;
                    }
                    break;
                }

                $thumbWidth = 25;
                $thumbHeight = 25;

                echo '<td><a href="index.php?onpub=EditImage&amp;ID=' . $ID . '" title="Edit"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'edit.png" width="60" height="25" alt="Edit" title="Edit" border="0" /></a></td>' . "\n";
                echo '<td></td>' . "\n";

                echo '</tr>' . "\n";

                if ( $counter + 1 == 2 ) {
                    $counter = 0;
                }
                else {
                    $counter++;
                }

                $index++;
            }
        }
        else {
            if ( $this->keywords ) {
                echo '<tr>' . "\n";
                $widget = new OnpubWidgetSearch( $totalImages, $this->keywords, $this->fullTextSearch );
                $widget->display();
                echo '</tr>' . "\n";
                echo '<tr>' . "\n";
                echo '<td>Your search did not yield any results. <a href="javascript:clearSearchField(); submitForm();">Display all images</a>.</td>' . "\n";
                echo '</tr>' . "\n";
            }
            else {
                if ( $this->sectionID ) {
                }
                else {
                    echo '<tr>' . "\n";
                    echo '<td>There are 0 images on file. <a href="index.php?onpub=UploadImages">Upload Images</a>.</td>' . "\n";
                    echo '</tr>' . "\n";
                }
            }
        }

        if ( $totalImages ) {
            echo '<tr>' . "\n";
            $widget = new OnpubWidgetStats( $totalImages, $this->keywords, $this->sectionID, "Image", "" );
            $widget->display();
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }
}

?>
