<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2008, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.7
 */
class OnpubNewSection
{
    private $pdo;
    private $osection;
    private $public;

    function __construct( PDO $pdo, OnpubSection $osection, $public = false )
    {
        $this->pdo = $pdo;
        $this->osection = $osection;
        $this->public = $public;
    }

    public function display()
    {
        $owebsites = new OnpubWebsites( $this->pdo );
        $osections = new OnpubSections( $this->pdo );

        try {
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->orderBy = "name";
            $queryOptions->order = "ASC";
            $websites = $owebsites->select( $queryOptions );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubWidgetHeader( "New Section" );
        $widget->display();

        echo '<form action="index.php" method="post" enctype="multipart/form-data">' . "\n";

        echo '<table border="0" cellspacing="0" cellpadding="5">' . "\n";
        echo '<tr>' . "\n";

        if ( $this->osection->name === null ) {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="name" value="' . htmlentities( $this->osection->name ) . '" /> <img src="gui/icons/exclamation.png" align="top" alt="Required field" title="Required field" /></td>' . "\n";
        }
        else {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="name" value="' . htmlentities( $this->osection->name ) . '" /></td>' . "\n";
        }

        echo '</tr>' . "\n";

        if ( $this->osection->parentID ) {
            $sectionIDs = array();
            $sectionIDs[] = $this->osection->parentID;
        }
        else {
            $sectionIDs = null;
        }

        $list = new OnpubWidgetSections( $sectionIDs, $websites, $osections, array(), "Parent Section", false, "sectionID", null, $this->osection->parentID );
        $list->display();

        $widget = new OnpubWidgetWebsites( $this->osection->websiteID, $websites, "section" );
        $widget->display();

        if ( sizeof( $websites ) ) {
            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<input type="checkbox" id="id_public" name="public" value="1" /> <label for="id_public">Public</label>' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td align="left"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'create.png" border="0" alt="" /></a></td>' . "\n";
        echo '</tr>' . "\n";
        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="NewSectionProcess" /></div>';

        echo '</form>' . "\n";

        $widget = new OnpubWidgetFooter();
        $widget->display();
    }

    public function validate()
    {
        $osections = new OnpubSections( $this->pdo );
        $valid = true;

        if ( $this->osection->parentID === "" ) {
            $this->osection->parentID = null;
        }

        if ( !$this->osection->name ) {
            $this->osection->name = null;
            $valid = false;
        }

        if ( !$this->osection->websiteID ) {
            $this->osection->websiteID = ""; // set to empty to signify validation error
            $valid = false;
        }
        else {
            if ( $this->osection->parentID ) {
                try {
                    $parent = $osections->get( $this->osection->parentID );
                }
                catch ( PDOException $e ) {
                    throw $e;
                }

                if ( $parent->websiteID != $this->osection->websiteID ) {
                    $this->osection->parentID = "";
                    $valid = false;
                }
            }
        }

        return $valid;
    }

    public function process()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->insert( $this->osection, $this->public );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>